@@ -45,4 +45,5 @@ class Binomial:
         return(res)
 def test_func():
     bn = Binomial()
-    assert bn.pdf,bn.cdf,bn.sf,bn.stats
+    assert bn.pdf,bn.cdf
+    assert bn.sf,bn.stats
