@@ -35,4 +35,5 @@ class Exponential:
 
 def test_func():
     ex = Exponential()
-    assert ex.pdf,ex.cdf,ex.sf,ex.stats
+    assert ex.pdf,ex.cdf
+    assert ex.sf,ex.stats
