@@ -35,4 +35,5 @@ class Multinomial:
 
 def test_func():
     mn = Multinomial()
-    assert mn.pdf,mn.cov,mn.stats
+    assert mn.pdf,mn.cov
+    assert mn.stats
