@@ -38,4 +38,5 @@ class Normal:
 
 def test_func():
     n = Normal()
-    assert n.pdf,n.cdf,n.sf,n.stats
+    assert n.pdf,n.cdf
+    assert n.sf,n.stats
