@@ -39,4 +39,5 @@ class Poisson:
 
 def test_func():
     p = Poisson()
-    assert p.pdf,p.cdf,p.sf,p.stats
+    assert p.pdf,p.cdf
+    assert p.sf,p.stats
